/**
 * @author chuzhixin 1204505056@qq.com （不想保留author可删除）
 * @description router全局配置，如有必要可分文件抽离，其中asyncRoutes只有在intelligence模式下才会用到，vip文档中已提供路由的基础图标与小清新图标的配置方案，请仔细阅读
 */

import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/layouts'
import EmptyLayout from '@/layouts/EmptyLayout'
import { publicPath, routerMode } from '@/config'

Vue.use(VueRouter)
export const constantRoutes = [
  /*{
    path: '/login',
    component: () => import('@/views/login/login'),
    hidden: true,
  },*/
  {
    path: '/logOn',
    name: '登录',
    component: () => import('@/views/login/login'),
    hidden: true,
  },
  {
    path: '/register',
    component: () => import('@/views/register/index'),
    hidden: true,
  },
  {
    path: '/401',
    name: '401',
    component: () => import('@/views/401'),
    hidden: true,
  },
  {
    path: '/404',
    name: '404',
    component: () => import('@/views/404'),
    hidden: true,
  },
]

export const asyncRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/index',
    meta: { title: ' ' },
  },
  {
    path: '/index',
    alwaysShow: true,
    component: Layout,
    name: 'index',
    meta: { title: '应用魔方', icon: 'home' },
    children: [
      {
        path: '',
        name: '',
        component: () => import('@/views/rubik/rubikList'),
        meta: {
          title: '应用魔方',
        },
      },
    ],
  },
  {
    path: '/application',
    component: Layout,
    redirect: 'noRedirect',
    name: 'application',
    alwaysShow: true,
    meta: { title: '权限管理', icon: 'credit-card' },
    children: [
      {
        path: 'applicationList',
        name: 'applicationList',
        component: () => import('@/views/application/applicationList'),
        meta: {
          title: '应用管理',
        },
      },
      {
        path: 'nodeInfoList',
        name: 'nodeInfoList',
        component: () => import('@/views/nodeInfo/nodeInfoList'),
        meta: {
          title: '节点管理',
        },
      },
      {
        path: 'addApplication',
        name: 'addApplication',
        hidden: true,
        component: () => import('@/views/application/addApplication'),
        meta: {
          title: '编辑应用',
        },
      },
    ],
  },
  {
    path: '/nodeInfo',
    component: Layout,
    redirect: 'noRedirect',
    name: 'nodeInfo',
    alwaysShow: true,
    hidden: true,
    meta: { title: '节点管理', icon: 'credit-card' },
    children: [
      {
        path: 'nodeInfoList',
        name: 'nodeInfoList',
        component: () => import('@/views/nodeInfo/nodeInfoList'),
        meta: {
          title: '节点列表',
        },
      },
      {
        path: 'addNodeInfo',
        name: 'addNodeInfo',
        hidden: true,
        component: () => import('@/views/nodeInfo/addNodeInfo'),
        meta: {
          title: '编辑节点',
        },
      },
    ],
  },
  {
    path: '/roleInfo',
    component: Layout,
    redirect: 'noRedirect',
    name: 'roleInfo',
    alwaysShow: true,
    meta: { title: '角色管理', icon: 'credit-card' },
    children: [
      {
        path: 'roleInfoList',
        name: 'roleInfoList',
        component: () => import('@/views/roleInfo/roleInfoList'),
        meta: {
          title: '角色列表',
        },
      },
      {
        path: 'addRoleInfo',
        name: 'addRoleInfo',
        hidden: true,
        component: () => import('@/views/roleInfo/addRoleInfo'),
        meta: {
          title: '编辑角色',
        },
      },
    ],
  },
  {
    path: '/userInfo',
    component: Layout,
    redirect: 'noRedirect',
    name: 'userInfo',
    alwaysShow: true,
    meta: { title: '用户管理', icon: 'credit-card' },
    children: [
      {
        path: 'userinfoList',
        name: 'userinfoList',
        component: () => import('@/views/userInfo/userInfoList'),
        meta: {
          title: '用户列表',
        },
      },
      {
        path: 'addUserInfo',
        name: 'addUserInfo',
        hidden: true,
        component: () => import('@/views/userInfo/addUserInfo'),
        meta: {
          title: '编辑用户',
        },
      },
    ],
  },
  {
    path: '/error',
    component: EmptyLayout,
    redirect: 'noRedirect',
    name: 'Error',
    hidden: true,
    meta: { title: '错误页', icon: 'bug' },
    children: [
      {
        hidden: true,
        path: '401',
        name: 'Error401',
        component: () => import('@/views/401'),
        meta: { title: '401' },
      },
      {
        path: '404',
        hidden: true,
        name: 'Error404',
        component: () => import('@/views/404'),
        meta: { title: '404' },
      },
    ],
  },
  {
    path: '*',
    redirect: '/404',
    hidden: true,
  },
]

const router = new VueRouter({
  base: publicPath,
  mode: routerMode,
  scrollBehavior: () => ({
    y: 0,
  }),
  routes: constantRoutes,
})
//注释的地方是允许路由重复点击，如果你觉得框架路由跳转规范太过严格可选择放开
const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location, onResolve, onReject) {
  if (onResolve || onReject)
    return originalPush.call(this, location, onResolve, onReject)
  return originalPush.call(this, location).catch((err) => err)
}

export function resetRouter() {
  router.matcher = new VueRouter({
    base: publicPath,
    mode: routerMode,
    scrollBehavior: () => ({
      y: 0,
    }),
    routes: constantRoutes,
  }).matcher
}

export default router
